@@ -1,4 +1,5 @@
 from itertools import product
+from random import random
 
 def AND(*a):
     return int(all(a))
@@ -24,20 +25,23 @@ def XOR(*a):
     else:
         return 0
 
-def TABLE(f):
+def XNOR(*a):
+    return NOT(XOR(*a))
+
+def TABLE(f,r=1):
     n = f.__code__.co_argcount
     args = f.__code__.co_varnames[:n]
     print(args)
-    for p in product([0,1], repeat=n):
+    for p in assigniter(f,r):
         y = f(*p)
-        s = f.__name__ + ": " + ",".join([f"{a}={v}" for a,v in zip(args,p)])
-        s += f" -> y={y}"
+        #s = f.__name__ + ": " + ",".join([f"{a}={v}" for a,v in zip(args,p)])
+        #s += f" -> y={y}"
         #print(s)
         print(f"{f.__name__}{p} = {y}")
 
 def EQCHECK(f, g):
     n = f.__code__.co_argcount
-    args = f.__code__.co_varnames[:n]
+    #args = f.__code__.co_varnames[:n]
     res = True
     for p in product([0,1], repeat=n):
         y1 = f(*p)
@@ -51,4 +55,12 @@ def EQCHECK(f, g):
         print("NO")
     return res
 
+def assigniter(f,r=1):
+    n = f.__code__.co_argcount
+    #args = f.__code__.co_varnames[:n]
+    for p in product([0,1], repeat=n):
+        if random()>r:
+            continue
+        yield p
+
 
